..
   # SPDX-FileCopyrightText: Copyright (c) 2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
   # SPDX-License-Identifier: Apache-2.0
   #
   # Licensed under the Apache License, Version 2.0 (the "License");
   # you may not use this file except in compliance with the License.
   # You may obtain a copy of the License at
   #
   # http://www.apache.org/licenses/LICENSE-2.0
   #
   # Unless required by applicable law or agreed to in writing, software
   # distributed under the License is distributed on an "AS IS" BASIS,
   # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   # See the License for the specific language governing permissions and
   # limitations under the License.

.. _samples:


Samples
--------

There are three different types APIs available to consume CVCUDA functionality:

1. C API
2. C++ API
3. Python API

The next section documents the samples showing various use cases across these APIs.


.. toctree::
    :maxdepth: 1

    C++ <samples/cpp_samples>
    Python <samples/python_samples>
